//#############################################################################
// playex.h
// 
// Header for callers to ESOUND.DLL
//#############################################################################

#define WM_PLAYEX (WM_USER+1)
#define WM_PLAYEX2 (WM_USER+2)

#define ESOUND_LOOP	0x00010000L
#define ESOUND_STOP 0x00020000L
#define ESOUND_PLAY 0x00000001L
#define ESOUND_END	0x00000002L

typedef struct _tabplayex
{	char *pszWave;	// Wave filename (with optional path)
	unsigned long dwFlags;
		// ESOUND_ flags as above
		//    First two are set by caller
		//			LOOP requests looped sound
		//			STOP requests stop the looped sound
		//    Others are set by ESOUND:
		//          PLAY inidicates sound is started
		//			END indicates sound is finished (or failed to start)
} PLAYEX, *LPPLAYEX;

typedef struct _IPCSound
{	unsigned char bCmd;
	unsigned char bSpare;
	unsigned short uStat;
	DWORD dwRef;
	char szWav[248];
} IPCSound;

//#############################################################################
//
// EXAMPLES of External usage

// METHOD 1: FS linkage
// ====================
//
// Add import table entry for module 0x00000101.
// Suppose this is named "esoundentry", then obtain "PlaySound" procedure
// address by:
//
//	if (ImportTable.esoundentry.fnptr)
//	{	BOOL (FSAPI *PlaySound)(int, char *) = 
//				*((PVOID *) ImportTable.esoundentry.fnptr + 7);
//
// or "PlaySound2" procedure entry address by:
//
//	if (ImportTable.esoundentry.fnptr)
//	{	BOOL (FSAPI *PlaySound2)(int, char *) = 
//				*((PVOID *) ImportTable.esoundentry.fnptr + 8);
//
//
// "PlaySound" is the simplest. There are no options and no feedback.
//
// Whenever a sound is to be played:
//
//		if (PlaySound) result = PlaySound(n, pszsound);
//
// result is FALSE if it wasn't played, TRUE if it was
//
// n gives the Module reference for "esound.cfg", so the sound can be
// specifically directed by "Mn" entries. Set to 0 if the default is
// to be used.
//
// If a specific 'n' value is given the sound name string can optionally be
// omitted. The sound to be used is then selected in the esound.cfg file
// instead.
//
// The sound name can include a full path (with drive). Otherwise it is
// assumed to refer to a file in the FS98 sound folder, or in a sub-folder
// from there.

// "PlaySound2" provides Looping and feedback options:
//
//		if (PlaySound2)
//		{	static PLAYEX play;	// MUST be static, not dynamic,
//								// since ESOUND will write to it!
//			
//			play.pszWave = "wavename";
//			play.dwFlags = 0L; // ESOUND_LOOP for looped sound
//
//			result = PlaySound(n, &play);
//
//				// Result is FALSE if this fails, TRUE if ok.
//
// play.dwFlags gives ESOUND_PLAY set whilst the sound is playing, ESOUND_END
// when it stops. The PLAYEX structure is then free for re-use.
//
// For a Looped sound, stop it later by a call with dwFlags set with
// ESOUND_STOP. The SAME PLAYEX structure must be provided in this call, as
// it is this pointer value which identifies which sound to stop.


// METHOD 2: Windows Message
// =========================
//
// Get FS's main Window Handle by
//
//		HWND hwndFS = FindWindowEx(NULL, NULL, "FS98MAIN", NULL);
//
// or MS combat FS by
//
//		HWND hwndFS = FindWindowEx(NULL, NULL, "MSCFSMAIN", NULL);
//
// Then get esound's window handle:
//
//		HWND hwndES = FindWindowEx(hwndFS, NULL, "FS98esound", NULL);
//
// To play a sound:
//
//		if (hwndES) PostMessage(hwndES, WM_PLAYEX, n, (LPARAM) pszsound);
//
// SendMessage can be used if you need confirmation or a more immediate sound.
// A zero return indicates failure to play. The parameters 'n' and the sound
// name string pointer are as above, and the same options apply.

// The more complex method uses PLAYEX structures, thus:
//
//		{	static PLAYEX play;	// MUST be static, not dynamic,
//								// since ESOUND will write to it!
//			
//			play.pszWave = "wavename";
//			play.dwFlags = 0L; // ESOUND_LOOP for looped sound
//
//			PostMessage(hwndES, WM_PLAYEX2, n, (LPARAM) &play);
//
// The options for looping and the flags returned are as described above.

//################################################################################
